; Example 10  LayerZero.lsp
; This routine will change a selection to layer "0" using Entity List modification
(defun C:LayerZero (/ lstSelection ; list of selected item and selection point
                      entSelection ; Entity name of selection
                      lstEntity    ; Entity List of selection
                   )
 (if (setq lstSelection (entsel "\nSelect item on screen: "))
  (progn
   (setq entSelection (car lstSelection)
         lstEntity    (entget entSelection)
         lstEntity    (subst (cons 8 "0")(assoc 8 lstEntity) lstEntity)
   )
   (entmod lstEntity)
  )
 )
)

; Example 9: VDOT.lsp
; This routine will list the methods and properties of an activeX object
(defun C:VDOT (/ lstSelection ; list of selected item and selection point
                 entSelection ; Entity name of selection
                 objSelection ; VisualLISP ActiveX object (vla-object) of Selection
              )
 (vl-load-com)
 (if (setq lstSelection (entsel "\nSelect item on screen: "))
  (progn
   (setq entSelection (car lstSelection)
         objSelection (vlax-ename->vla-object entSelection)
   )
   (vlax-dump-object objSelection 'T)
   (textscr)   
  )
 )
)


; Example 8: vl-Layerzero.lsp
; This routine will change a selection to layer "0" using ActiveX Property manipulation
(defun C:vl-LayerZero (/ lstSelection ; list of selected item and selection point
                         entSelection ; Entity name of selection
                         objSelection ; VisualLISP ActiveX object (vla-object) of Selection
                     )
 (vl-load-com)
 (if (setq lstSelection (entsel "\nSelect item on screen: "))
  (progn
   (setq entSelection (car lstSelection)
         objSelection (vlax-ename->vla-object entSelection)
   )
   (vla-put-layer objSelection "0")
 ; (vlax-put-property objSelection "layer" "0") ; Alternate 
 ; (vlax-put objSelection "layer" "0")          ; Alternate
  )
 )
) 

; Example 7: SS-Layerzero.lsp
; This routine will change a selection set to layer "0" using ActiveX Property manipulation
(defun C:SS-LayerZero (/ entSelection ; Entity name of selection
                         intCount     ; Iteration Counter for Selections Set
                         objSelection ; VisualLISP ActiveX object (vla-object) of Selection
                         ssSelections ; Selection Set of Entities
                     )
 (vl-load-com)
 (princ "\nCreate Selection set to be changed to layer 0: ")
 (if (setq ssSelections (ssget))
  (repeat (setq intCount (sslength ssSelections))
   (setq intCount     (1- intCount)
         entSelection (ssname ssSelections intCount)
         objSelection (vlax-ename->vla-object entSelection)
   )
   (vla-put-layer objSelection "0")
  )
 )
)

; Example 6: CHRadius .lsp
; This routine will change the radius property of a selection set of circles
(defun C:CHRadius (/ intCount     ; Iteration Counter for Selections Set
                     objSelection ; VisualLISP ActiveX object (vla-object) of Selection
                     sngRadius    ; Single real number for New Radius length 
                     ssSelections ; Selection Set of Entities
                  )
 (vl-load-com)
 (princ "\nCreate Selection set to be changed to layer 0: ")
 (setq ssSelections (ssget (list (cons 0 "CIRCLE"))) ; <- Selection Set Filter
       sngRadius    (getdist "\nEnter new radius: ") ; <- User input get distance
 )
 (if (and ssSelections 
          (> sngRadius 0.0)
     )
  (repeat (setq intCount (sslength ssSelections))
   (setq intCount     (1- intCount)
         objSelection (vlax-ename->vla-object 
                       (ssname ssSelections intCount)
                      )
   )
   (vla-put-radius objSelection sngRadius); <- Change Radius Property
  )
 )
)

; Example 5: ScaleRadius .lsp
; This routine will scale the radius properties of a selection set of circles
(defun C:ScaleRadius (/ intCount       ; Iteration Counter for Selections Set
                        objSelection   ; vla-object of Selection
                        sngScaleFactor ; Scale factor for radius property 
                        ssSelections   ; Selection Set of Entities
                     )
 (vl-load-com)
 (princ "\nCreate Selection set to be changed to layer 0: ")
 (setq ssSelections   (ssget (list (cons 0 "CIRCLE")))   ; <- Selection Set Filter
       sngScaleFactor (getdist "\nEnter scale factor: ") ; <- User input 
 )
 (if (and ssSelections 
          (> sngScaleFactor 0.0)
     )
  (repeat (setq intCount (sslength ssSelections))
   (setq intCount     (1- intCount)
         objSelection (vlax-ename->vla-object 
                       (ssname ssSelections intCount)
                      )
   )
   (vla-put-radius objSelection (* (vla-get-radius objSelection) sngScaleFactor))  
  )
 )
)

; Example 4: UpperCase .lsp
; This routine will change selected to be uppercase letters. 
(defun C:UpperCase (/ intCount       ; Iteration Counter for Selections Set
                      objSelection   ; vla-object of Selection
                      ssSelections   ; Selection Set of Entities
                   )
 (vl-load-com)
 (princ "\nSelect text to be uppercase: ")
 (setq ssSelections   (ssget (list (cons 0 "TEXT,MTEXT"))))   ; <- Selection Set Filter 
 (if ssSelections 
     
  (repeat (setq intCount (sslength ssSelections))
   (setq intCount     (1- intCount)
         objSelection (vlax-ename->vla-object 
                       (ssname ssSelections intCount)
                      )
   )
   (vla-put-textstring objSelection (strcase (vla-get-textstring objSelection)))
  )
 )
)

;Example 3: LowerCase .lsp
; This routine will change selected to be uppercase letters. 
(defun C:LowerCase (/ intCount       ; Iteration Counter for Selections Set
                      objSelection   ; vla-object of Selection
                      ssSelections   ; Selection Set of Entities
                   )
 (vl-load-com)
 (princ "\nSelect text to be lowercase: ")
 (setq ssSelections   (ssget (list (cons 0 "TEXT,MTEXT"))))   ; <- Selection Set Filter 
 (if ssSelections 
     
  (repeat (setq intCount (sslength ssSelections))
   (setq intCount     (1- intCount)
         objSelection (vlax-ename->vla-object 
                       (ssname ssSelections intCount)
                      )
   )
   (vla-put-textstring objSelection (strcase (vla-get-textstring objSelection) 'T))
  )
 )
)

; Example 2: Prefix .lsp
; This routine will add a string prefix to selected text. 
(defun C:Prefix (/ intCount       ; Iteration Counter for Selections Set
                   objSelection   ; vla-object of Selection
                   ssSelections   ; Selection Set of Entities
                   strPrefix      ; Prefix text string
                )
 (vl-load-com)
 (princ "\nSelect text to be modified: ")
 (setq ssSelections   (ssget (list (cons 0 "TEXT,MTEXT")))   ; <- Selection Set Filter 
       strPrefix      (getstring "\nEnter string Prefix: ")  ; <- String entry 
 )
 (if ssSelections      
  (repeat (setq intCount (sslength ssSelections))
   (setq intCount     (1- intCount)
         objSelection (vlax-ename->vla-object 
                       (ssname ssSelections intCount)
                      )
   )
   (vla-put-textstring objSelection (strcat strPrefix (vla-get-textstring objSelection)))
  )
 )
)


